zbx

package module
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 12, 2020 License: MIT Imports: 6 Imported by: 0

README

zbx

Go Report Card Godoc Releases LICENSE

Package zbx is a Zabbix Agent implementation in golang that allows your application to act as a zabbix agent and respond to simple requests.

It is compatible with Zabbix version 4.0 and 4.2 only. It does not support TLS or PSK encryption at this time.

An example of how to implement an agent can be seen in cmd/zbx/main.go

Documentation

Overview

Package zbx is a Zabbix Agent implementation in golang that allows your application to act as a zabbix agent and respond to simple requests.

It is compatible with Zabbix version 4.0 and 4.2 only. It does not support TLS or PSK encryption at this time.

An example of how to implement an agent can be seen in cmd/zbx/main.go

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Start

func Start(agent Agent, address string) error

Start start the zabbix agent. Will block and return on fatal error

Types

type Agent

type Agent interface {
	// GetItem is called for each individual request from the zabbix server/proxy for an item
	// Your value will be encoded as a string and returned to the server
	// If error is not nil, it will be sent back to the server
	// If (nil, nil) is returned then it is assumed the key is unknown.
	GetItem(key string) (interface{}, error)
}

Agent describes the interface for a Zabbix Agent

Directories

Path Synopsis
cmd
key command
zbx command

Jump to