Documentation
¶
Overview ¶
Package zbx is a Zabbix Agent implementation in golang that allows your application to act as a zabbix agent and respond to simple requests.
It is compatible with Zabbix version 4.0 and 4.2 only. It does not support TLS or PSK encryption at this time.
An example of how to implement an agent can be seen in cmd/zbx/main.go
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Agent ¶
type Agent interface {
// GetItem is called for each individual request from the zabbix server/proxy for an item
// Your value will be encoded as a string and returned to the server
// If error is not nil, it will be sent back to the server
// If (nil, nil) is returned then it is assumed the key is unknown.
GetItem(key string) (interface{}, error)
}
Agent describes the interface for a Zabbix Agent
Click to show internal directories.
Click to hide internal directories.